==> libgtop-2.0.7.tar.gz: libgtop-2.0.7/sysdeps/kernel/uptime.c <==
/* $Id: uptime.c,v 1.19 2003/10/19 16:55:36 carlos Exp $ */

/* Copyright (C) 1998-99 Martin Baulig
   This file is part of LibGTop 1.0.

   Contributed by Martin Baulig <martin@home-of-linux.org>, April 1998.

   LibGTop is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License,
   or (at your option) any later version.

   LibGTop is distributed in the hope that it will be useful, but WITHOUT
   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
   for more details.

   You should have received a copy of the GNU General Public License
   along with LibGTop; see the file COPYING. If not, write to the
   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#include <config.h>
#include <glibtop/error.h>
#include <glibtop/uptime.h>

#include "kernel.h"

static unsigned long _glibtop_sysdeps_uptime =
(1 << GLIBTOP_UPTIME_UPTIME) + (1 << GLIBTOP_UPTIME_IDLETIME);

/* Init function. */

void
glibtop_init_uptime_s (glibtop *server)
{
	server->sysdeps.uptime = _glibtop_sysdeps_uptime;
}

/* Provides uptime and idle time. */

void
glibtop_get_uptime_s (glibtop *server, glibtop_uptime *buf)
{
	union table tbl;
	
	glibtop_init_s (&server, GLIBTOP_SYSDEPS_UPTIME, 0);

	memset (buf, 0, sizeof (glibtop_uptime));

	if (table (TABLE_UPTIME, &tbl, NULL))
		glibtop_error_io_r (server, "table(TABLE_UPTIME)");
	
	buf->flags = _glibtop_sysdeps_uptime;

#if 0
	fprintf (stderr, "Table (%u) = %lu, %lu\n",
		 TABLE_UPTIME, tbl.uptime.uptime, tbl.uptime.idle);
#endif

	buf->uptime = (double) tbl.uptime.uptime / HZ;
	buf->idletime = (double) tbl.uptime.idle / HZ;
}

==> libgtop-2.8.0.tar.gz: libgtop-2.8.0/sysdeps/kernel/uptime.c <==
/* $Id: uptime.c,v 1.21 2004/06/09 18:52:21 bdejean Exp $ */

/* Copyright (C) 1998-99 Martin Baulig
   This file is part of LibGTop 1.0.

   Contributed by Martin Baulig <martin@home-of-linux.org>, April 1998.

   LibGTop is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License,
   or (at your option) any later version.

   LibGTop is distributed in the hope that it will be useful, but WITHOUT
   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
   for more details.

   You should have received a copy of the GNU General Public License
   along with LibGTop; see the file COPYING. If not, write to the
   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#include <config.h>
#include <glibtop/error.h>
#include <glibtop/uptime.h>

#include <time.h>

#include "kernel.h"

static const unsigned long _glibtop_sysdeps_uptime =
(1 << GLIBTOP_UPTIME_UPTIME) + (1 << GLIBTOP_UPTIME_IDLETIME);

/* Init function. */

void
glibtop_init_uptime_s (glibtop *server)
{
	server->sysdeps.uptime = _glibtop_sysdeps_uptime;
}

/* Provides uptime and idle time. */

void
glibtop_get_uptime_s (glibtop *server, glibtop_uptime *buf)
{
	union table tbl;

	glibtop_init_s (&server, GLIBTOP_SYSDEPS_UPTIME, 0);

	memset (buf, 0, sizeof (glibtop_uptime));

	if (table (TABLE_UPTIME, &tbl, NULL))
		glibtop_error_io_r (server, "table(TABLE_UPTIME)");

	buf->flags = _glibtop_sysdeps_uptime;

#if 0
	fprintf (stderr, "Table (%u) = %lu, %lu\n",
		 TABLE_UPTIME, tbl.uptime.uptime, tbl.uptime.idle);
#endif

	buf->uptime = (double) tbl.uptime.uptime / HZ;
	buf->idletime = (double) tbl.uptime.idle / HZ;
	buf->boot_time = (guint64) time(NULL) - (tbl.uptime.uptime / HZ);
}
